@@ -171,7 +171,7 @@ def compute_accuracy(x, y):
     return np.average(np.equal(x, y).all(axis=1))
 
 
-def median_error(q_75: float, q_25: float, n: int):
+def median_error(q_75: float, q_25: float, n: int) -> int:
     assert q_75 >= q_25 >= 0.0, f"q_75 {q_75} < q_25 {q_25}"
     return 1.57*(q_75-q_25)/np.sqrt(n)
 
@@ -181,6 +181,6 @@ if __name__ == "__main__":
 
 
 __author__ = 'J. Agustin BARRACHINA'
-__version__ = '0.0.20'
+__version__ = '0.0.21'
 __maintainer__ = 'J. Agustin BARRACHINA'
 __email__ = 'joseagustin.barra@gmail.com; jose-agustin.barrachina@centralesupelec.fr'
